# Text Representation

Text representation commands are used to determine how objects are printed on the Python command line.

## Classes

### redentABQ

```{eval-rst}
.. automodule:: abaqus.TextRepresentation.redentABQ
    :members:
    :special-members: __init__
    :show-inheritance:
```

### textRepr

```{eval-rst}
.. automodule:: abaqus.TextRepresentation.textRepr
    :members:
    :special-members: __init__
    :show-inheritance:
```

### TextReprOptions

```{eval-rst}
.. autoclass:: abaqus.TextRepresentation.TextReprOptions.TextReprOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
